export interface _Function {
    /**
     * Function ID.
     * @readonly
     */
    id?: string | null;
    /**
     * Revision number, which increments by 1 each time the function is updated.
     * To prevent conflicting changes,
     * the current revision must be passed when updating the function.
     *
     * Ignored when creating a function.
     * @readonly
     */
    revision?: string | null;
    /**
     * Date and time the function was created.
     * @readonly
     */
    createdDate?: Date | null;
    /**
     * Date and time the function was last updated.
     * @readonly
     */
    updatedDate?: Date | null;
    /** The function's app extension ID. */
    functionExtensionId?: string | null;
    /** Function name. */
    functionName?: string | null;
    /**
     * Activation status
     * @readonly
     */
    activationStatus?: ActivationStatus;
    /** ID of the app that defines the function. */
    appId?: string | null;
    /** The function's app extension name. */
    functionExtensionName?: string | null;
    /** Function template extension id */
    functionTemplateExtensionId?: string | null;
    /** Form template extension id */
    formTemplateExtensionId?: string | null;
}
export declare enum ActivationStatus {
    /** Activation status is unknown. */
    UNKNOWN_STATUS = "UNKNOWN_STATUS",
    /** Function is activated. */
    ACTIVE = "ACTIVE",
    /** Function is deactivated. */
    INACTIVE = "INACTIVE",
    /** Function is saved but has never been activated. */
    DRAFT = "DRAFT"
}
export interface CreateFunctionRequest {
    /** Function to create. */
    function: _Function;
}
export interface CreateFunctionResponse {
    /** The created function. */
    function?: _Function;
}
export interface GetFunctionRequest {
    /** ID of the function to retrieve. */
    functionId: string;
}
export interface GetFunctionResponse {
    /** The requested function. */
    function?: _Function;
}
export interface UpdateFunctionRequest {
    /** Function to update. */
    function: _Function;
}
export interface UpdateFunctionResponse {
    /** Updated function. */
    function?: _Function;
}
export interface DeleteFunctionRequest {
    /** ID of the function to delete. */
    functionId: string;
}
export interface DeleteFunctionResponse {
}
export interface QueryFunctionsRequest {
    /** WQL expression. */
    query?: CursorQuery;
}
export interface CursorQuery extends CursorQueryPagingMethodOneOf {
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    cursorPaging?: CursorPaging;
    /**
     * Filter object in the following format:
     * `"filter" : {
     * "fieldName1": "value1",
     * "fieldName2":{"$operator":"value2"}
     * }`
     * Example of operators: `$eq`, `$ne`, `$lt`, `$lte`, `$gt`, `$gte`, `$in`, `$hasSome`, `$hasAll`, `$startsWith`, `$contains`
     */
    filter?: Record<string, any> | null;
    /**
     * Sort object in the following format:
     * `[{"fieldName":"sortField1","order":"ASC"},{"fieldName":"sortField2","order":"DESC"}]`
     */
    sort?: Sorting[];
}
/** @oneof */
export interface CursorQueryPagingMethodOneOf {
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    cursorPaging?: CursorPaging;
}
export interface Sorting {
    /** Name of the field to sort by. */
    fieldName?: string;
    /** Sort order. */
    order?: SortOrder;
}
export declare enum SortOrder {
    ASC = "ASC",
    DESC = "DESC"
}
export interface CursorPaging {
    /** Maximum number of items to return in the results. */
    limit?: number | null;
    /**
     * Pointer to the next or previous page in the list of results.
     *
     * Pass the relevant cursor token from the `pagingMetadata` object in the previous call's response.
     * Not relevant for the first request.
     */
    cursor?: string | null;
}
export interface QueryFunctionsResponse {
    /** List of functions. */
    functions?: _Function[];
    /** Metadata for the paginated results. */
    pagingMetadata?: CursorPagingMetadata;
}
export interface CursorPagingMetadata {
    /** Number of items returned in the response. */
    count?: number | null;
    /** Cursor strings that point to the next page, previous page, or both. */
    cursors?: Cursors;
    /**
     * Whether there are more pages to retrieve following the current page.
     *
     * + `true`: Another page of results can be retrieved.
     * + `false`: This is the last page.
     */
    hasNext?: boolean | null;
}
export interface Cursors {
    /** Cursor string pointing to the next page in the list of results. */
    next?: string | null;
    /** Cursor pointing to the previous page in the list of results. */
    prev?: string | null;
}
export interface ListValuesByFieldRequest {
    /** Field to list values for. */
    field?: string;
}
export interface ListValuesByFieldResponse {
    /** List of values for the field. */
    fieldAndCount?: FieldAndCount[];
}
export interface FieldAndCount {
    /** Field value. */
    field?: string;
    /** Number of times the value occurs. */
    count?: number;
}
export interface DomainEvent extends DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
    /**
     * Unique event ID.
     * Allows clients to ignore duplicate webhooks.
     */
    id?: string;
    /**
     * Assumes actions are also always typed to an entity_type
     * Example: wix.stores.catalog.product, wix.bookings.session, wix.payments.transaction
     */
    entityFqdn?: string;
    /**
     * This is top level to ease client code dispatching of messages (switch on entity_fqdn+slug)
     * This is although the created/updated/deleted notion is duplication of the oneof types
     * Example: created/updated/deleted/started/completed/email_opened
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example: 2020-04-26T13:57:50.699Z */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number defining the order of updates to the underlying entity.
     * For example, given that some entity was updated at 16:00 and than again at 16:01,
     * it is guaranteed that the sequence number of the second update is strictly higher than the first.
     * As the consumer, you can use this value to ensure that you handle messages in the correct order.
     * To do so, you will need to persist this number on your end, and compare the sequence number from the
     * message against the one you have stored. Given that the stored number is higher, you should ignore the message.
     */
    entityEventSequence?: string | null;
}
/** @oneof */
export interface DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
}
export interface EntityCreatedEvent {
    entityAsJson?: string;
    /** Indicates the event was triggered by a restore-from-trashbin operation for a previously deleted entity */
    restoreInfo?: RestoreInfo;
}
export interface RestoreInfo {
    deletedDate?: Date | null;
}
export interface EntityUpdatedEvent {
    /**
     * Since platformized APIs only expose PATCH and not PUT we can't assume that the fields sent from the client are the actual diff.
     * This means that to generate a list of changed fields (as opposed to sent fields) one needs to traverse both objects.
     * We don't want to impose this on all developers and so we leave this traversal to the notification recipients which need it.
     */
    currentEntityAsJson?: string;
}
export interface EntityDeletedEvent {
    /** Entity that was deleted */
    deletedEntityAsJson?: string | null;
}
export interface ActionEvent {
    bodyAsJson?: string;
}
export interface Empty {
}
export interface MessageEnvelope {
    /** App instance ID. */
    instanceId?: string | null;
    /** Event type. */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
    /** Stringify payload. */
    data?: string;
}
export interface IdentificationData extends IdentificationDataIdOneOf {
    /** ID of a site visitor that has not logged in to the site. */
    anonymousVisitorId?: string;
    /** ID of a site visitor that has logged in to the site. */
    memberId?: string;
    /** ID of a Wix user (site owner, contributor, etc.). */
    wixUserId?: string;
    /** ID of an app. */
    appId?: string;
    /** @readonly */
    identityType?: WebhookIdentityType;
}
/** @oneof */
export interface IdentificationDataIdOneOf {
    /** ID of a site visitor that has not logged in to the site. */
    anonymousVisitorId?: string;
    /** ID of a site visitor that has logged in to the site. */
    memberId?: string;
    /** ID of a Wix user (site owner, contributor, etc.). */
    wixUserId?: string;
    /** ID of an app. */
    appId?: string;
}
export declare enum WebhookIdentityType {
    UNKNOWN = "UNKNOWN",
    ANONYMOUS_VISITOR = "ANONYMOUS_VISITOR",
    MEMBER = "MEMBER",
    WIX_USER = "WIX_USER",
    APP = "APP"
}
interface _FunctionNonNullableFields {
    activationStatus: ActivationStatus;
}
export interface CreateFunctionResponseNonNullableFields {
    function?: _FunctionNonNullableFields;
}
export interface GetFunctionResponseNonNullableFields {
    function?: _FunctionNonNullableFields;
}
export interface UpdateFunctionResponseNonNullableFields {
    function?: _FunctionNonNullableFields;
}
export interface QueryFunctionsResponseNonNullableFields {
    functions: _FunctionNonNullableFields[];
}
export {};
