import { transformError as sdkTransformError } from '@wix/sdk-runtime/transform-error';
import { queryBuilder } from '@wix/sdk-runtime/query-builder';
import { renameKeysFromSDKRequestToRESTRequest, renameKeysFromRESTResponseToSDKResponse, } from '@wix/sdk-runtime/rename-all-nested-keys';
import * as ambassadorWixFunctionsV1Function from './functions-v1-function-functions.http.js';
export var ActivationStatus;
(function (ActivationStatus) {
    /** Activation status is unknown. */
    ActivationStatus["UNKNOWN_STATUS"] = "UNKNOWN_STATUS";
    /** Function is activated. */
    ActivationStatus["ACTIVE"] = "ACTIVE";
    /** Function is deactivated. */
    ActivationStatus["INACTIVE"] = "INACTIVE";
    /** Function is saved but has never been activated. */
    ActivationStatus["DRAFT"] = "DRAFT";
})(ActivationStatus || (ActivationStatus = {}));
export var SortOrder;
(function (SortOrder) {
    SortOrder["ASC"] = "ASC";
    SortOrder["DESC"] = "DESC";
})(SortOrder || (SortOrder = {}));
export var WebhookIdentityType;
(function (WebhookIdentityType) {
    WebhookIdentityType["UNKNOWN"] = "UNKNOWN";
    WebhookIdentityType["ANONYMOUS_VISITOR"] = "ANONYMOUS_VISITOR";
    WebhookIdentityType["MEMBER"] = "MEMBER";
    WebhookIdentityType["WIX_USER"] = "WIX_USER";
    WebhookIdentityType["APP"] = "APP";
})(WebhookIdentityType || (WebhookIdentityType = {}));
/**
 * Creates a function.
 * @param _function - Function to create.
 * @public
 * @documentationMaturity preview
 * @requiredField function
 * @requiredField function.appId
 * @requiredField function.functionExtensionId
 * @permissionId FUNCTIONS.FUNCTION_CREATE
 * @permissionScope Manage Functions
 * @permissionScopeId SCOPE.DC-FUNCTIONS.MANAGE-FUNCTIONS
 * @applicableIdentity APP
 * @returns The created function.
 * @fqn wix.functions.api.v1.Functions.CreateFunction
 */
export async function createFunction(_function) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        function: _function,
    });
    const reqOpts = ambassadorWixFunctionsV1Function.createFunction(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data)?.function;
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { function: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['_function']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Retrieves a function.
 * @param functionId - ID of the function to retrieve.
 * @public
 * @documentationMaturity preview
 * @requiredField functionId
 * @permissionId FUNCTIONS.FUNCTION_READ
 * @permissionScope Manage Functions
 * @permissionScopeId SCOPE.DC-FUNCTIONS.MANAGE-FUNCTIONS
 * @applicableIdentity APP
 * @returns The requested function.
 * @fqn wix.functions.api.v1.Functions.GetFunction
 */
export async function getFunction(functionId) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        functionId: functionId,
    });
    const reqOpts = ambassadorWixFunctionsV1Function.getFunction(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data)?.function;
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { functionId: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['functionId']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Updates a function.
 *
 * Each time the function is updated,
 * `revision` increments by 1.
 * The existing `revision` must be passed when updating the function.
 * This ensures you're working with the latest version of the function
 * and prevents unintended overwrites.
 * @param _id - Function ID.
 * @public
 * @documentationMaturity preview
 * @requiredField _id
 * @requiredField function
 * @requiredField function.revision
 * @permissionId FUNCTIONS.FUNCTION_UPDATE
 * @permissionScope Manage Functions
 * @permissionScopeId SCOPE.DC-FUNCTIONS.MANAGE-FUNCTIONS
 * @applicableIdentity APP
 * @returns Updated function.
 * @fqn wix.functions.api.v1.Functions.UpdateFunction
 */
export async function updateFunction(_id, _function) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        function: { ..._function, id: _id },
    });
    const reqOpts = ambassadorWixFunctionsV1Function.updateFunction(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data)?.function;
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: { function: '$[1]' },
            explicitPathsToArguments: { 'function.id': '$[0]' },
            singleArgumentUnchanged: false,
        }, ['_id', '_function']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Deletes a function.
 *
 * Deleting a function permanently removes it from the Function List
 * in the site dashboard.
 * @param functionId - ID of the function to delete.
 * @public
 * @documentationMaturity preview
 * @requiredField functionId
 * @permissionId FUNCTIONS.FUNCTION_DELETE
 * @permissionScope Manage Functions
 * @permissionScopeId SCOPE.DC-FUNCTIONS.MANAGE-FUNCTIONS
 * @applicableIdentity APP
 * @fqn wix.functions.api.v1.Functions.DeleteFunction
 */
export async function deleteFunction(functionId) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        functionId: functionId,
    });
    const reqOpts = ambassadorWixFunctionsV1Function.deleteFunction(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { functionId: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['functionId']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Retrieves a list of functions, given the provided paging, filtering, and sorting.
 *
 * To learn about working with _Query_ endpoints, see
 * [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language),
 * [Sorting and Paging](https://dev.wix.com/api/rest/getting-started/pagination),
 * and [Field Projection](https://dev.wix.com/api/rest/getting-started/field-projection).
 * @public
 * @documentationMaturity preview
 * @permissionScope Manage Functions
 * @permissionScopeId SCOPE.DC-FUNCTIONS.MANAGE-FUNCTIONS
 * @permissionId FUNCTIONS.FUNCTION_READ
 * @applicableIdentity APP
 * @fqn wix.functions.api.v1.Functions.QueryFunctions
 */
export function queryFunctions() {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[0];
    return queryBuilder({
        func: async (payload) => {
            const reqOpts = ambassadorWixFunctionsV1Function.queryFunctions(payload);
            sideEffects?.onSiteCall?.();
            try {
                const result = await httpClient.request(reqOpts);
                sideEffects?.onSuccess?.(result);
                return result;
            }
            catch (err) {
                sideEffects?.onError?.(err);
                throw err;
            }
        },
        requestTransformer: (query) => {
            const args = [query, {}];
            return renameKeysFromSDKRequestToRESTRequest({
                ...args?.[1],
                query: args?.[0],
            });
        },
        responseTransformer: ({ data }) => {
            const transformedData = renameKeysFromRESTResponseToSDKResponse(data);
            return {
                items: transformedData?.functions,
                pagingMetadata: transformedData?.pagingMetadata,
            };
        },
        errorTransformer: (err) => {
            const transformedError = sdkTransformError(err, {
                spreadPathsToArguments: {},
                explicitPathsToArguments: { query: '$[0]' },
                singleArgumentUnchanged: false,
            });
            throw transformedError;
        },
        pagingMethod: 'CURSOR',
        transformationPaths: {},
    });
}
//# sourceMappingURL=functions-v1-function-functions.universal.js.map